@@ -1,11 +1,7 @@
-import os
-from sortedcontainers import SortedKeyList
-from anytree.search import findall
-from abc import ABC, abstractclassmethod
 from typing import Tuple, List
 
-from .tree import Tree, DataTree
-from .container import CatalogueContainer, FileItem, DirItem
+from .tree import Tree, FSTree
+from .container import CatalogueContainer
 from .fsaction import FSActionDelete
 from .logger import logger
 
@@ -17,7 +13,7 @@ class Catalogue:
         1. A CatalogueContainer for files, which is just for file-based sorting
         2. A CatalogueContainer for directories, which is just for
         directory-based sorting
-        3. The DataTree. Nodes in the tree are
+        3. The FSTree. Nodes in the tree are
         FileItems or DirItems which inherit from anytree's NodeMixin.
         Each node in turn holds CatalogueContainers for holding children
         items.
@@ -25,10 +21,15 @@ class Catalogue:
 
     def __init__(self, hash_files=False):
         # self.filter_checks = []
+        # self.files = CatalogueContainer()
+        # self.dirs = CatalogueContainer()
+        self.tree = FSTree()
         self.files = CatalogueContainer()
         self.dirs = CatalogueContainer()
-        self.tree = DataTree()
         self.mirror_trees = []
+        self.num_files = 0
+        self.num_dirs = 0
+        self.total_space = 0
         self.hash_files = hash_files
 
     def registerMirrorTrees(self, trees: List[Tree]):
@@ -43,26 +44,32 @@ class Catalogue:
 
         self.files = CatalogueContainer()
         self.dirs = CatalogueContainer()
-        self.tree = DataTree()
+        self.tree = FSTree()
+        self.num_files = 0
+        self.num_dirs = 0
+        self.total_space = 0
 
         logger.info("Start creating catalogue (bottom up).")
 
         try:
-            for parent_item, file_items, dir_items in self.tree.treeFromFSBottomUp(
-                start=start
-            ):
+            for parent_item, file_items in self.tree.treeFromFSBottomUp(start=start):
+                self.num_dirs += 1
+                self.num_files += len(file_items)
+
                 self.dirs.addItem(parent_item)
                 for item in file_items:
                     self.files.addItem(item)
-                for item in dir_items:
-                    self.dirs.addItem(item)
-
                 for tree in self.mirror_trees:
                     tree.insertDirItem(parent_item)
 
+            # minus top dir
+            self.num_dirs -= 1
+
         except Exception as e:
             logger.error(f"Error when walking the directory tree: {e}")
 
+        self.total_space = self.tree.root_node.size
+
         logger.info("Finished creating catalogue.")
 
     # def addFilterCheck(self, filter_check: FilterCheck):
@@ -93,24 +100,34 @@ class Catalogue:
             fs_action (Action): Action object
             paths (List[str]): full paths to files or dirs
         """
-        items = self.tree.deleteByIDs(selection, self.files, self.dirs)
+        logger.debug(f"Deleting iids {selection} from tree.")
+        # reverse sort, so greatest iids, i.e. "oldest ancestors"
+        # are deleted first which potentially deletes
+        # smaller iids in the list if they are their children
+        # and also guaranteeing that ancestors are not updated multiple
+        # times by their descendants (e.g. by a file and then by it's parent
+        # folder)
+        for iid in sorted(selection, reverse=True):
+            item = self.tree.findByID(f"{iid}")
 
-        for item in items:
+            if item:
+                self.tree.deleteSubtree(item, self.files, self.dirs, self.mirror_trees)
 
-            logger.debug(f"Deleting item {item}.")
+                # in case an item has been deleted on disk by the user / os
+                try:
+                    fs_action = FSActionDelete()
+                    fs_action.execute(item)
+                except FileNotFoundError as fne:
+                    logger.error(
+                        f"Cannot delete item since it does not seem to exist anymore: {fne}"
+                    )
 
-            if isinstance(item, FileItem):
-                logger.debug(f"Removing {item} from file list.")
-                self.files.removeItemByValue(item)
-
-            if isinstance(item, DirItem):
-                logger.debug(f"Removing {item} from dir list.")
-                self.dirs.removeItemByValue(item)
-
-            fs_action = FSActionDelete()
-            fs_action.execute(item)
-
-        logger.info(f"Removed {len(items)} item from catalogue and disk.")
+        self.num_files = len(self.files)
+        self.num_dirs = len(self.dirs) - 1  # minus top dir
+        if self.tree.root_node:
+            self.total_space = self.tree.root_node.size
+        else:
+            self.total_space = 0
 
 
 # class FilterCheck(ABC):
